# flake8: noqa

"""
    local-api

    local api for linksaas desktop  # noqa: E501

    The version of the OpenAPI document: 0.1.2
    Contact: panleiming@linksaas.pro
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from linksaas_local_api.api_client import ApiClient

# import Configuration
from linksaas_local_api.configuration import Configuration

# import exceptions
from linksaas_local_api.exceptions import OpenApiException
from linksaas_local_api.exceptions import ApiAttributeError
from linksaas_local_api.exceptions import ApiTypeError
from linksaas_local_api.exceptions import ApiValueError
from linksaas_local_api.exceptions import ApiKeyError
from linksaas_local_api.exceptions import ApiException
